@@ -3,7 +3,7 @@ import os
 import  numpy as np
 from moviepy.editor import AudioFileClip
 from commFunction import get_rms,get_ave_rms,get_one_channel_data,get_file_duration,get_data_array
-
+from formatConvert import pcm2wav
 
 def get_wav_from_mp4(mp4file):
     """
@@ -24,7 +24,7 @@ def get_wav_from_mp4(mp4file):
     return newFileName
 
 
-def isSlience(Filename =None):
+def isSlience(Filename =None,section=None,channels=1, bits=16, sample_rate=16000):
     """
     Parameters
     ----------
@@ -35,23 +35,34 @@ def isSlience(Filename =None):
 
     """
     suffix = os.path.splitext(Filename)[-1]
+
     if suffix == '.mp4':
         Filename = get_wav_from_mp4(Filename)
-        ins, _,_ = get_data_array(Filename)
     if suffix == '.pcm':
-        pcmf = open(Filename, 'rb')
-        pcmdata = pcmf.read()
-        ins = np.frombuffer(pcmdata, dtype=np.int16)
-        pcmf.close()
+        Filename = pcm2wav(Filename,channels,bits,sample_rate)
     if suffix == '.wav':
-        ins,_,_ = get_data_array(Filename)
+        pass
+    lenth,fs = get_file_duration(Filename)
+    data = get_one_channel_data(Filename)
+    if section is None:
+        startTime = 0
+        endTime = lenth
+    else:
+        startTime = section[0]
+        endTime = section[1]
+    if startTime > lenth or startTime > endTime:
+        raise TypeError('start point is larger than the file lenth :' + str(suffix))
+    if endTime > lenth:
+        endTime = lenth
+    ins = data[int(startTime*fs):int(endTime*fs)]
+
     dBrmsValue = get_rms(ins)#20*math.log10(get_rms(ins)/32767+ 1.0E-6)
     print(dBrmsValue)
     if dBrmsValue > -70:
         return False
     else:
         for n in range(len(ins)//480):
-            curdata = ins[480*n:480*(n+1)]
+            curdata = curdata[480*n:480*(n+1)]
             dBrmsValue = get_rms(curdata)#20 * math.log10(get_rms(curdata) / 32767 + 1.0E-6)
             print(dBrmsValue)
             if dBrmsValue > -60:
@@ -116,5 +127,5 @@ def get_rms_level(wavFileName=None,rmsMode='total',section=None):
 
 if __name__ == '__main__':
     ref = r'E:\02_ai_vad\5_aecm_1648612346.wav'
-    print(get_rms_level(ref,rmsMode='average',section=[1,6]),)
+    print(isSlience(ref,section=[0,20]),)
     #print(audioFormat(ref))
\ No newline at end of file
