@@ -29,6 +29,11 @@ def cal_mos_infer(testFile=None):
     args['deg'] = testFile
     nisqa = nisqaModel(args)
     df = nisqa.predict()
+    try:
+        npyfile = testFile[:-4] + '_mel48.npy'
+        os.remove(npyfile)
+    except:
+        print('AI MOS file delete err!')
     return df['mos_pred'].values[0]
 
 
